Learn R Programming

aplpack (version 1.1.1)

spin3R: spin3R

Description

Simple spin function to rotate and to inspect a 3-dimensional cloud of points

Usage

spin3R(x, alpha = 1, delay = 0.015, na.rm=FALSE)

Arguments

x
(nx3)-matrix of points
alpha
angle between successive projections
delay
delay in seconds between two plots
na.rm
if TRUE 'NA' values are removed otherwise exchanged by mean

Details

spin3R computes two-dimensional projections of (nx3)-matrix x and plots them on the graphics devise. The cloud of points is rotated step by step. The rotation is defined by a tcl/tk control widget. spin3R requires tcl/tk package of R.

References

Cleveland, W. S. / McGill, M. E. (1988): Dynamic Graphics for Statistics. Wadsworth & Brooks/Cole, Belmont, California.

See Also

spin of S-Plus

Examples

Run this code
xyz<-matrix(rnorm(300),100,3)
  # now start:     spin3R(xyz)

Run the code above in your browser using DataLab