Usage
stem.leaf(data, unit, m, Min, Max, rule.line = c("Dixon", "Velleman", "Sturges"),
style = c("Tukey", "bare"), trim.outliers = TRUE, depths = TRUE,
reverse.negative.leaves = TRUE, na.rm = FALSE)Arguments
unit
leaf unit, as a power of 10 (e.g., 100, .01);
if unit is missing unit is choosen by stem.leaf.
m
number of parts (1, 2, or 5) into which each stem will be separated;
if m is missing the number of parts/stem
(m) is choosen by stem.leaf.
Min
smallest non-outlying value; omit for automatic choice.
Max
largest non-outlying value; omit for automatic choice.
rule.line
the rule to use for choosing the desired number of lines
in the display; "Dixon" = 10*log10(n); "Velleman" = 2*sqrt(n);
"Sturges" = 1 + log2(n); the default is "Dixon".
style
"Tukey" (the default) for "Tukey-style" divided stems;
"bare" for divided stems that simply repeat the stem digits.
trim.outliers
if TRUE (the default), outliers are placed on LO and
HI stems.
depths
if TRUE (the default), print a column of "depths" to the left of the
stems; the depth of the stem containing the median is the stem-count enclosed in
parentheses.
reverse.negative.leaves
if TRUE (the default), reverse direction the leaves on negative
stems (so, e.g., the leaf 9 comes before the leaf 8, etc.).
na.rm
if TRUE 'NA' values are removed otherwise exchanged by mean